@@ -1187,9 +1187,9 @@ enum {
    XCF_Exit /* 94 */,		XCF_Netlist /* 95 */,
    XCF_Swap /* 96 */,		XCF_Pin_Label /* 97 */,
    XCF_Pin_Global /* 98 */,	XCF_Info_Label /* 99 */,
-   XCF_Connectivity /* 100 */,	XCF_Sim /* 101 */,
-   XCF_SPICE /* 102 */,		XCF_PCB /* 103 */,
-   XCF_SPICEflat /* 104 */,
+   XCF_Graphic	/* 100 */,	XCF_Connectivity /* 101 */,
+   XCF_Sim /* 102 */,		XCF_SPICE /* 103 */,
+   XCF_PCB /* 104 */,		XCF_SPICEflat /* 105 */,
    NUM_FUNCTIONS
 };
 
